==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/component/signalprovisionsandrequirements/impl/ProvidedSignalSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.ProvidedSignalBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.ProvidedSignalBodySetImpl;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.ProvidedExecutablePropertySet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.ProvidedSignal;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.ProvidedSignalSet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl.ProvidedExecutablePropertySetImpl;
import io.ciera.tool.sql.ooaofooa.invocation.SignalInvocationSet;
import io.ciera.tool.sql.ooaofooa.invocation.impl.SignalInvocationSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.SignalEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.SignalEventSetImpl;

import java.util.Arrays;
import java.util.List;

import ooaofooa.datatypes.ActionDialect;
import ooaofooa.datatypes.ParseStatus;


public class ProvidedSignalSetImpl extends InstanceSet<ProvidedSignalSet,ProvidedSignal> implements ProvidedSignalSet {

    // attributes
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( ProvidedSignal providedsignal : this ) providedsignal.setName( m_Name );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( ProvidedSignal providedsignal : this ) providedsignal.setId( ref_Id );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( ProvidedSignal providedsignal : this ) providedsignal.setDescrip( m_Descrip );
    }
    @Override
    public void setSuc_Pars( ParseStatus m_Suc_Pars ) throws XtumlException {
        for ( ProvidedSignal providedsignal : this ) providedsignal.setSuc_Pars( m_Suc_Pars );
    }
    @Override
    public void setAction_Semantics_internal( String m_Action_Semantics_internal ) throws XtumlException {
        for ( ProvidedSignal providedsignal : this ) providedsignal.setAction_Semantics_internal( m_Action_Semantics_internal );
    }
    @Override
    public void setAction_Semantics( String m_Action_Semantics ) throws XtumlException {
        for ( ProvidedSignal providedsignal : this ) providedsignal.setAction_Semantics( m_Action_Semantics );
    }
    @Override
    public void setDialect( ActionDialect m_Dialect ) throws XtumlException {
        for ( ProvidedSignal providedsignal : this ) providedsignal.setDialect( m_Dialect );
    }


    // selections
    @Override
    public ProvidedExecutablePropertySet R4503_is_a_ProvidedExecutableProperty() throws XtumlException {
        ProvidedExecutablePropertySet providedexecutablepropertyset = new ProvidedExecutablePropertySetImpl();
        for ( ProvidedSignal providedsignal : this ) providedexecutablepropertyset.add( providedsignal.R4503_is_a_ProvidedExecutableProperty() );
        return providedexecutablepropertyset;
    }
    @Override
    public SignalEventSet R528_SignalEvent() throws XtumlException {
        SignalEventSet signaleventset = new SignalEventSetImpl();
        for ( ProvidedSignal providedsignal : this ) signaleventset.add( providedsignal.R528_SignalEvent() );
        return signaleventset;
    }
    @Override
    public SignalInvocationSet R663_SignalInvocation() throws XtumlException {
        SignalInvocationSet signalinvocationset = new SignalInvocationSetImpl();
        for ( ProvidedSignal providedsignal : this ) signalinvocationset.addAll( providedsignal.R663_SignalInvocation() );
        return signalinvocationset;
    }
    @Override
    public ProvidedSignalBodySet R686_ProvidedSignalBody() throws XtumlException {
        ProvidedSignalBodySet providedsignalbodyset = new ProvidedSignalBodySetImpl();
        for ( ProvidedSignal providedsignal : this ) providedsignalbodyset.add( providedsignal.R686_ProvidedSignalBody() );
        return providedsignalbodyset;
    }


    @Override
    public ProvidedSignal nullElement() {
        return ProvidedSignalImpl.EMPTY_PROVIDEDSIGNAL;
    }

    @Override
    public ProvidedSignalSet emptySet() {
      return new ProvidedSignalSetImpl();
    }

    @Override
    public ProvidedSignalSet value() {
        return this;
    }

    @Override
    public List<ProvidedSignal> elements() {
        ProvidedSignal[] elements = toArray(new ProvidedSignal[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/component/signalprovisionsandrequirements/impl/ProvidedSignalSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.ProvidedSignalBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.ProvidedSignalBodySetImpl;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.ProvidedExecutablePropertySet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.ProvidedSignal;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.ProvidedSignalSet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl.ProvidedExecutablePropertySetImpl;
import io.ciera.tool.sql.ooaofooa.invocation.SignalInvocationSet;
import io.ciera.tool.sql.ooaofooa.invocation.impl.SignalInvocationSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.SignalEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.SignalEventSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;

import ooaofooa.datatypes.ActionDialect;
import ooaofooa.datatypes.ParseStatus;


public class ProvidedSignalSetImpl extends InstanceSet<ProvidedSignalSet,ProvidedSignal> implements ProvidedSignalSet {

    public ProvidedSignalSetImpl() {
    }

    public ProvidedSignalSetImpl(Comparator<? super ProvidedSignal> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setAction_Semantics( String m_Action_Semantics ) throws XtumlException {
        for ( ProvidedSignal providedsignal : this ) providedsignal.setAction_Semantics( m_Action_Semantics );
    }
    @Override
    public void setAction_Semantics_internal( String m_Action_Semantics_internal ) throws XtumlException {
        for ( ProvidedSignal providedsignal : this ) providedsignal.setAction_Semantics_internal( m_Action_Semantics_internal );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( ProvidedSignal providedsignal : this ) providedsignal.setDescrip( m_Descrip );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( ProvidedSignal providedsignal : this ) providedsignal.setName( m_Name );
    }
    @Override
    public void setSuc_Pars( ParseStatus m_Suc_Pars ) throws XtumlException {
        for ( ProvidedSignal providedsignal : this ) providedsignal.setSuc_Pars( m_Suc_Pars );
    }
    @Override
    public void setDialect( ActionDialect m_Dialect ) throws XtumlException {
        for ( ProvidedSignal providedsignal : this ) providedsignal.setDialect( m_Dialect );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( ProvidedSignal providedsignal : this ) providedsignal.setId( ref_Id );
    }


    // selections
    @Override
    public ProvidedExecutablePropertySet R4503_is_a_ProvidedExecutableProperty() throws XtumlException {
        ProvidedExecutablePropertySet providedexecutablepropertyset = new ProvidedExecutablePropertySetImpl();
        for ( ProvidedSignal providedsignal : this ) providedexecutablepropertyset.add( providedsignal.R4503_is_a_ProvidedExecutableProperty() );
        return providedexecutablepropertyset;
    }
    @Override
    public SignalEventSet R528_SignalEvent() throws XtumlException {
        SignalEventSet signaleventset = new SignalEventSetImpl();
        for ( ProvidedSignal providedsignal : this ) signaleventset.add( providedsignal.R528_SignalEvent() );
        return signaleventset;
    }
    @Override
    public SignalInvocationSet R663_SignalInvocation() throws XtumlException {
        SignalInvocationSet signalinvocationset = new SignalInvocationSetImpl();
        for ( ProvidedSignal providedsignal : this ) signalinvocationset.addAll( providedsignal.R663_SignalInvocation() );
        return signalinvocationset;
    }
    @Override
    public ProvidedSignalBodySet R686_ProvidedSignalBody() throws XtumlException {
        ProvidedSignalBodySet providedsignalbodyset = new ProvidedSignalBodySetImpl();
        for ( ProvidedSignal providedsignal : this ) providedsignalbodyset.add( providedsignal.R686_ProvidedSignalBody() );
        return providedsignalbodyset;
    }


    @Override
    public ProvidedSignal nullElement() {
        return ProvidedSignalImpl.EMPTY_PROVIDEDSIGNAL;
    }

    @Override
    public ProvidedSignalSet emptySet() {
      return new ProvidedSignalSetImpl();
    }

    @Override
    public ProvidedSignalSet emptySet(Comparator<? super ProvidedSignal> comp) {
      return new ProvidedSignalSetImpl(comp);
    }

    @Override
    public ProvidedSignalSet value() {
        return this;
    }

    @Override
    public List<ProvidedSignal> elements() {
        ProvidedSignal[] elements = toArray(new ProvidedSignal[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}
